A Java domain specific language representation of the CSS web framework including exporting Java generated CSS to stylesheet files.


Download latest version
=========================================================================

https://github.com/corgrath/Java-CSS-Library/downloads/


A Quick guide
===============================================================================

Here is a quick guide for common usage.


Basic usage
-------------------------------------------------------------------------------

Declaration:

	CSS css = new CSS();
	css.setColor("white");
	css.setBackgroundColor("red");
	
or:

	CSS css = new CSS().setColor("white").setBackgroundColor("red");
	
Usage:

	String div = "<div style=\"" + css + "\">This is a div</div>";

Will output:

	<div style="color: white; background-color: red;">This is a div</div>
	
	
Example of using a class
-------------------------------------------------------------------------------

Declaration:

	public final class MyStylesheet {
	
		public static final CSS alertText = new CSS() {
	
			{
				setColor("white");
				setBackgroundColor("red");
			}
	
		};
	
	}
	
Example of using class selectors
-------------------------------------------------------------------------------

Declaration:

	public final class MyStylesheet {
	
		public static final CSS alertText = new CSS() {
	
			{
				setColor("white");
				setBackgroundColor("red");
			}
	
		};
	
	}
	
Usage:	
	
	String div = "<div class=\"" + css.getClassName() + "\">This is a div</div>";

Will output:

	<div class="c588234b5af6e8cefd17b76f95bae9fea">This is a div</div>
	
Please note that MyStylesheet needs to be exported to a .css file in order to this to work. More information below.
	

Example of adding a pseudo class, such as link:hover
-------------------------------------------------------------------------------

Pseudo classes can be defined the various ways. However, please note that these will only be written when using CSS.export method.

	public final class MyStylesheet {
	
		public static final CSS link = new CSS() {
	
			{
				setTextDecoration(TextDecoration.NONE);
				addPseudoSelector(PseudoSelector.HOVER, new CSS() {
	
					{
						setTextDecoration(TextDecoration.UNDERLINE);
					}
	
				});
			}
	
		};
	
	}

Will output:

	/*
	 * MyStylesheet.link
	 */
	
	.8354e9b3ce585febf8c43e960f9a2132 {
		text-decoration: none;
	}
	
	.8354e9b3ce585febf8c43e960f9a2132:hover {
		hover: underline;
	}

Example of using units such as pixels (px) or percentages (%)
-------------------------------------------------------------------------------

	public final class MyStylesheet {
	
		public static final CSS box = new CSS() {
	
			{
				setPadding(PX(50)); // pixels px
				setWidth(PCT(75)); // percent %
			}
	
		};
	
	}

Will output:

	.b5245ce630907207628772c1921d888c {
		width: 75%;
		padding: 50px;
	}


Example of using the "auto" value
-------------------------------------------------------------------------

	public final class MyStylesheet {
	
		public static final CSS box = new CSS() {
	
			{
				setMargin(PX(50), AUTO);
			}
	
		};
	
	}

Will output:

	.ad85285bde8fc1ad1dacb7424402d9dc {
		margin: 50px auto;
	}


Export CSS objects to a stylesheet file
-------------------------------------------------------------------------

Create a class with a number of defined static CSS fields, such as:

	public final class MyStylesheet {
	
		public static final CSS alertText = new CSS() {
	
			{
				setColor("white");
				setBackgroundColor("red");
			}
	
		};
	
		public static final CSS box = new CSS() {
	
			{
				setMargin(PX(50), AUTO);
			}
	
		};
	
		public static final CSS link = new CSS() {
	
			{
				setTextDecoration(TextDecoration.NONE);
				addPseudoSelector(PseudoSelector.HOVER, new CSS() {
	
					{
						setTextDecoration(TextDecoration.UNDERLINE);
					}
	
				});
			}
	
		};
	
	}
	
Create a method that will export the styles:

	public class Main {
	
		public static void main(String[] args) throws Exception {
	
			File file = new File("test_generation/com/osbcp/css/stylesheet.css");
	
			CSS.export(MyStylesheet.class, file, true);
	
		}
	
	} 
	
Running this code will create stylesheets.css with the following contents:

	/*
	 * MyStylesheet.alertText
	 */
	
	.4ce2dcc1e9be43c12f4637af6a68fbf4 {
		color: white;
		background-color: red;
	}
	
	/*
	 * MyStylesheet.box
	 */
	
	.ad85285bde8fc1ad1dacb7424402d9dc {
		margin: 50px auto;
	}
	
	/*
	 * MyStylesheet.link
	 */
	
	.8354e9b3ce585febf8c43e960f9a2132 {
		text-decoration: none;
	}
	
	.8354e9b3ce585febf8c43e960f9a2132:hover {
		hover: underline;
	}


Example of using an attribute selector
-------------------------------------------------------------------------

	public final class MyStylesheet {
	
		public static final CSS box = new CSS() {
	
			{
				setAttributeSelector("title", "W3Schools");
				setColor("blue");
			}
	
		};
	
	}

Will output:

	.ad85285bde8fc1ad1dacb7424402d9dc[title="W3Schools"] {
		color: blue;
	}


JavaDoc
========================================

http://dl.dropbox.com/u/8183146/persistent/projects/java_css_library/javadoc/index.html


Changes
========================================

v1.3 2011-09-03 Christoffer Pettersson

 * Added support for an attribute selector
 * Renamed CSS.setFontVariant(FontWeight) to CSS.setFontWeight(FontWeight)
 * Added CSS.setBackgroundPosition(Unit, Unit)
 * Renamed Display.INELINE to Display.INLINE
 * Minor JavaDoc comment tweaks
 * New test cases
 * New JavaDoc
 
v1.2 2011-08-29 Christoffer Pettersson

 * Added the visibility property

v1.1 2011-08-20 Christoffer Pettersson

 * Added more debug messages 
 * Removed id feature and added class name support
 * Fixed bug when writing pseudo selectors' css

v1.0 2011-08-09 Christoffer Pettersson

 * Initial release



Report problems
=========================================================================

Please report any problems here:

https://github.com/corgrath/Java-CSS-Library/issues/

License
=========================================================================

Java CSS Library - Copyright 2011 Christoffer Pettersson, christoffer@christoffer.me

Licensed under the Apache License, Version 2.0