/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.css;

import java.io.Serializable;

/**
 * Container class for an attribute selector
 * 
 * @see <a href="http://www.w3schools.com/css/css_attribute_selectors.asp">CSS Attribute Selectors</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

final class AttributeSelector implements Serializable {

	private static final long serialVersionUID = 1L;
	private Serializable attribute;
	private Serializable value;

	/**
	 * Creates a new attribute selector.
	 * 
	 * @param attribute The selector attribute.
	 */

	public AttributeSelector(final Serializable attribute) {
		this(attribute, "");
	}

	/**
	 * Creates a new attribute selector.
	 * 
	 * @param attribute The selector attribute.
	 * @param value The selector value.
	 */

	public AttributeSelector(final Serializable attribute, final Serializable value) {

		if (attribute == null || attribute.toString().length() == 0) {
			throw new IllegalArgumentException("Attribute cannot be empty.");
		}

		this.attribute = attribute;
		this.value = value;

	}

	@Override
	public String toString() {

		StringBuilder selector = new StringBuilder();

		selector.append("[" + attribute);

		if (value != null && value.toString().length() != 0) {
			selector.append("=\"" + value + "\"");
		}

		selector.append("]");

		return selector.toString();
	}

}