package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>background-repeat</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_background-repeat.asp">CSS background-repeat Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum BackgroundRepeat implements Serializable {

	/**
	 * The background image will be repeated both vertically and horizontally. This is default.
	 */

	REPEAT,

	/**
	 * The background image will be repeated only horizontally.
	 */

	REPEAT_X,

	/**
	 * The background image will be repeated only vertically.
	 */

	REPEAT_Y,

	/**
	 * The background-image will not be repeated.
	 */

	NO_REPEAT,

	/**
	 * Specifies that the setting of the background-repeat property should be inherited from the parent element.
	 */

	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}