package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>border-style</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_border-style.asp">CSS border-style Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum BorderStyle implements Serializable {

	/**
	 * Specifies no border.
	 */

	NONE,

	/**
	 * The same as "none", except in border conflict resolution for table elements.
	 */

	HIDDEN,

	/**
	 * Specifies a dotted border.
	 */

	DOTTED,

	/**
	 * 	Specifies a dashed border.
	 */

	DASHED,

	/**
	 * Specifies a solid border.
	 */

	SOLID,

	/**
	 * Specifies a double border.
	 */

	DOUBLE,

	/**
	 * Specifies a 3D grooved border. The effect depends on the border-color value.
	 */

	GROOVE,

	/**
	 * Specifies a 3D ridged border. The effect depends on the border-color value.
	 */

	RIDGE,

	/**
	 * 	Specifies a 3D inset border. The effect depends on the border-color value.
	 */

	INSET,

	/**
	 * Specifies a 3D outset border. The effect depends on the border-color value.
	 */

	OUTSET,

	/**
	 * Specifies that the border style should be inherited from the parent element.
	 */

	INHERT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}