package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>clear</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_class_clear.asp">http://www.w3schools.com/cssref/pr_class_clear.asp</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum Clear implements Serializable {

	/**
	 * No floating elements allowed on the left side.
	 */
	LEFT,

	/**
	 * No floating elements allowed on the right side.
	 */
	RIGHT,

	/**
	 * No floating elements allowed on either the left or the right side.
	 */
	BOTH,

	/**
	 * Default. Allows floating elements on both sides.
	 */
	NONE,

	/**
	 * Specifies that the value of the clear property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase();
	}

}