package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>cursor</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_class_cursor.asp">CSS cursor Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum Cursor implements Serializable {

	/**
	 * The cursor render as a pointer.
	 */
	POINTER,

	/**
	 * The cursor render as a crosshair.
	 */
	CROSSHAIR,

	/**
	 * The cursor indicates something that should be moved.
	 */
	MOVE,

	/**
	 * The cursor indicates text.
	 */
	TEXT,

	/**
	 * The cursor indicates that the program is busy.
	 */
	WAIT,

	/**
	 * The cursor indicates that help is available.
	 */
	HELP,

	/**
	 * The cursor indicates that the program is busy (in progress).
	 */
	PROGRESS,

	/**
	 * The default cursor.
	 */
	DEFAULT,

	/**
	 * Default. The browser sets a cursor.
	 */
	AUTO,

	/**
	 * The cursor indicates that an edge of a box is to be moved up (north).
	 */
	N_RESIZE,

	/**
	 * The cursor indicates that an edge of a box is to be moved up and right (north/east).
	 */
	NE_RESIZE,

	/**
	 * The cursor indicates that an edge of a box is to be moved up and left (north/west).
	 */
	NW_RESIZE,

	/**
	 * The cursor indicates that an edge of a box is to be moved down (south).
	 */
	S_RESIZE,

	/**
	 * The cursor indicates that an edge of a box is to be moved down and right (south/east).
	 */
	SE_RESIZE,

	/**
	 * The cursor indicates that an edge of a box is to be moved down and left (south/west).
	 */
	SW_RESIZE,

	/**
	 * The cursor indicates that an edge of a box is to be moved left (west).
	 */
	W_RESIZE,

	/**
	 * The cursor indicates that an edge of a box is to be moved right (east).
	 */
	E_RESIZE,

	/**
	 * Specifies that the value of the cursor property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}