package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>display</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_class_display.asp">CSS display Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum Display implements Serializable {

	/**
	 * The element will generate no box at all.
	 */
	NONE,

	/**
	 * The element will generate a block box (a line break before and after the element).
	 */
	BLOCK,

	/**
	 * The element will generate an inline box (no line break before or after the element). This is default.
	 */
	INLINE,

	/**
	 * The element will generate a block box, laid out as an inline box.
	 */
	INLINE_BLOCK,

	/**
	 * The element will generate an inline box (like &lt;table&gt;, with no line break before or after).
	 */
	INLINE_TABLE,

	/**
	 * The element will generate a block box, and an inline box for the list marker.
	 */
	LIST_ITEM,

	/**
	 * The element will generate a block or inline box, depending on context.
	 */
	RUN_IN,

	/**
	 * The element will behave like a table (like &lt;table&gt;, with a line break before and after).
	 */
	TABLE,

	/**
	 * The element will behave like a table caption (like &lt;caption&gt;).
	 */
	TABLE_CAPTION,

	/**
	 * The element will behave like a table cell.
	 */
	TABLE_CELL,

	/**
	 * The element will behave like a table column.
	 */
	TABLE_COLUMN,

	/**
	 * The element will behave like a table column group (like &lt;colgroup&gt;).
	 */
	TABLE_COLUMN_GROUP,

	/**
	 * The element will behave like a table footer row group.
	 */
	TABLE_FOOTER_GROUP,

	/**
	 * The element will behave like a table header row group.
	 */
	TABLE_HEADER_GROUP,

	/**
	 * The element will behave like a table row.
	 */
	TABLE_ROW,

	/**
	 * The element will behave like a table row group.
	 */
	TABLE_ROW_GROUP,

	/**
	 * Specifies that the value of the display property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}