package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>list-style-type</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_list-style-type.asp">CSS list-style-type Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum ListStyleType implements Serializable {

	/**
	 * The marker is traditional Armenian numbering.
	 */
	ARMENIAN,

	/**
	 * The marker is a circle.
	 */
	CIRCLE,

	/**
	 * The marker is plain ideographic numbers.
	 */
	CJK_IDEOGRAPHIC,

	/**
	 * The marker is a number. This is default for &lt;ol&gt;.
	 */
	DECIMAL,

	/**
	 * The marker is a number with leading zeros (01, 02, 03, etc.).
	 */
	DECIMAL_LEADING_ZERO,

	/**
	 * The marker is a filled circle. This is default for &lt;ul&gt;.
	 */
	DISC,

	/**
	 * The marker is traditional Georgian numbering.
	 */
	GEORGIAN,

	/**
	 * The marker is traditional Hebrew numbering.
	 */
	HEBREW,

	/**
	 * The marker is traditional Hiragana numbering.
	 */
	HIRAGANA,

	/**
	 * The marker is traditional Hiragana iroha numbering.
	 */
	HIRAGANA_IROHA,

	/**
	 * The value of the listStyleType property is inherited from parent element.
	 */
	INHERIT,

	/**
	 * The marker is traditional Katakana numbering.
	 */
	KATAKANA,

	/**
	 * The marker is traditional Katakana iroha numbering.
	 */
	KATAKANA_IROHA,

	/**
	 * The marker is lower-alpha (a, b, c, d, e, etc.).
	 */
	LOWER_ALPHA,

	/**
	 * The marker is lower-greek.
	 */
	LOWER_GREEK,

	/**
	 * The marker is lower-latin (a, b, c, d, e, etc.).
	 */
	LOWER_LATIN,

	/**
	 * The marker is lower-roman (i, ii, iii, iv, v, etc.).
	 */
	LOWER_ROMAN,

	/**
	 * No marker is shown.
	 */
	NONE,

	/**
	 * The marker is a square.
	 */
	SQUARE,

	/**
	 * The marker is upper-alpha (A, B, C, D, E, etc.).
	 */
	UPPER_ALPHA,

	/**
	 * The marker is upper-latin (A, B, C, D, E, etc.).
	 */
	UPPER_LATIN,

	/**
	 * The marker is upper-roman (I, II, III, IV, V, etc.).
	 */
	UPPER_ROMAN;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}