package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>outline-style</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_outline-style.asp">CSS outline-style Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum OutlineStyle implements Serializable {

	/**
	 * Specifies no outline.
	 */
	NONE,

	/**
	 * Specifies a dotted outline.
	 */
	DOTTED,

	/**
	 * Specifies a dashed outline.
	 */
	DASHED,

	/**
	 * Specifies a solid outline.
	 */
	SOLID,

	/**
	 * Specifies a double outliner.
	 */
	DOUBLE,

	/**
	 * Specifies a 3D grooved outline. The effect depends on the outline-color value.
	 */
	GROOVE,

	/**
	 * Specifies a 3D ridged outline. The effect depends on the outline-color value.
	 */
	RIDGE,

	/**
	 * Specifies a 3D inset outline. The effect depends on the outline-color value.
	 */
	INSET,

	/**
	 * Specifies a 3D outset outline. The effect depends on the outline-color value.
	 */
	OUTSET,

	/**
	 * Specifies that the outline style should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}