package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>overflow</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_pos_overflow.asp">CSS overflow Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum Overflow implements Serializable {

	/**
	 * The overflow is not clipped. It renders outside the element's box. This is default.
	 */
	VISIBLE,

	/**
	 * 	The overflow is clipped, and the rest of the content will be invisible.
	 */
	HIDDEN,

	/**
	 * 	The overflow is clipped, but a scroll-bar is added to see the rest of the content.
	 */
	SCROLL,

	/**
	 * If overflow is clipped, a scroll-bar should be added to see the rest of the content.
	 */
	AUTO,

	/**
	 * Specifies that the value of the overflow property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase();
	}

}