package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>position</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_class_position.asp">CSS position Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum Position implements Serializable {

	/**
	 * The element is positioned relative to its first positioned (not static) ancestor element.
	 */
	ABSOLUTE,

	/**
	 *The element is positioned relative to the browser window.
	 */
	FIXED,

	/**
	 * The element is positioned relative to its normal position, so "left:20" adds 20 pixels to the element's LEFT position.
	 */
	RELATIVE,

	/**
	 * Elements renders in order, as they appear in the document flow. This is default.
	 */
	STATIC,

	/**
	 * The value of the position property is inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase();
	}

}