package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>pseudo selectors, classes and elements</i>.
 * 
 * @see <a href="http://www.w3schools.com/css/css_pseudo_classes.asp">CSS Pseudo-classes</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum PseudoSelector implements Serializable {

	/**
	 * Example "a:link" selects all unvisited links.
	 */
	LINK,

	/**
	 * Example "a:visited" selects all visited links.
	 */
	VISITED,

	/**
	 * Example "a:active" selects the active link.
	 */
	ACTIVE,

	/**
	 * Example "a:hover" selects links on mouse over.
	 */
	HOVER,

	/**
	 * Example "input:focus " selects the input element which has focus.
	 */
	FOCUS,

	/**
	 * Example "p:first-letter" selects the first letter of every &lt;p&gt; element.
	 */
	FIRST_LETTER,

	/**
	 * Example "p:first-line" selects the first line of every &lt;p&gt; element.
	 */
	FIRST_LINE,

	/**
	 * Example "p:first-child" selects every &lt;p&gt; elements that is the first child of its parent.
	 */
	FIRST_CHILD,

	/**
	 * Example "p:before" insert content before every &lt;p&gt; element.
	 */
	BEFORE,

	/**
	 * Example "p:after" insert content after every &lt;p&gt; element.
	 */

	AFTER;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}