package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>text-decoration</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_text_text-decoration.asp">CSS text-decoration Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum TextDecoration implements Serializable {

	/**
	 * Defines a normal text. This is default.
	 */
	NONE,

	/**
	 * Defines a line below the text.
	 */
	UNDERLINE,

	/**
	 * Defines a line above the text.
	 */
	OVERLINE,

	/**
	 * Defines a line through the text.
	 */
	LINE_THROUGH,

	/**
	 * Defines a blinking text.
	 */
	BLINK,

	/**
	 * Specifies that the value of the text-decoration property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}