package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>text-transform</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_text_text-transform.asp">CSS text-transform Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum TextTransform implements Serializable {

	/**
	 * No capitalization. The text renders as it is. This is default.
	 */
	NONE,

	/**
	 * Transforms the first character of each word to uppercase.
	 */
	CAPITALIZE,

	/**
	 * Transforms all characters to uppercase.
	 */
	UPPERCASE,

	/**
	 * Transforms all characters to lowercase.
	 */
	LOWERCASE,

	/**
	 * Specifies that the value of the text-transform property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase();
	}

}