package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>vertical-align</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_pos_vertical-align.asp">CSS vertical-align Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum VerticalAlign implements Serializable {

	/**
	 * Align the baseline of the element with the baseline of the parent element. This is default.
	 */
	BASELINE,

	/**
	 * 	Aligns the element as it was subscript.
	 */
	SUB,

	/**
	 * Aligns the element as it was superscript.
	 */
	SUPER,

	/**
	 * The top of the element is aligned with the top of the tallest element on the line.
	 */
	TOP,

	/**
	 * The top of the element is aligned with the top of the parent element's font.
	 */
	TEXT_TOP,

	/**
	 * 	The element is placed in the middle of the parent element.
	 */
	MIDDLE,

	/**
	 * The bottom of the element is aligned with the lowest element on the line.
	 */
	BOTTOM,

	/**
	 * The bottom of the element is aligned with the bottom of the parent element's font.
	 */
	TEXT_BOTTOM,

	/**
	 * Specifies that the value of the vertical-align property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}