package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>visibility</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_class_visibility.asp">CSS visibility Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum Visibility implements Serializable {

	/**
	 * The element is visible. This is default.
	 */
	VISIBLE,

	/**
	 * The element is invisible (but still takes up space).
	 */
	HIDDEN,

	/**
	 * Only for table elements. collapse removes a row or column, but it does not affect the table layout.
	 */
	COLLAPSE,

	/**
	 * Specifies that the value of the display property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}