package com.osbcp.css.constants;

import java.io.Serializable;

/**
 * Values for the <i>white-space</i> property.
 * 
 * @see <a href="http://www.w3schools.com/cssref/pr_text_white-space.asp">CSS white-space Property</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public enum WhiteSpace implements Serializable {

	/**
	 * 	Sequences of whitespace will collapse into a single whitespace. Text will wrap when necessary. This is default.
	 */
	NORMAL,

	/**
	 * Sequences of whitespace will collapse into a single whitespace. Text will never wrap to the next line. The text continues on the same line until a &lt;br /&gt; tag is encountered.
	 */
	NOWRAP,

	/**
	 * Whitespace is preserved by the browser. Text will only wrap on line breaks Acts like the &lt;pre&gt; tag in HTML.
	 */
	PRE,

	/**
	 * Sequences of whitespace will collapse into a single whitespace. Text will wrap when necessary, and on line breaks.
	 */
	PRE_LINE,

	/**
	 * 	Whitespace is preserved by the browser. Text will wrap when necessary, and on line breaks.
	 */
	PRE_WRAP,

	/**
	 * 	Specifies that the value of the white-space property should be inherited from the parent element.
	 */
	INHERIT;

	@Override
	public String toString() {
		return name().toLowerCase().replace("_", "-");
	}

}