/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.css.unit;

/**
 * Represents a numeric CSS unit.
 * 
 * @see <a href="http://w3schools.com/cssref/css_units.asp">CSS Units</a>
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 * 
 */

public abstract class NumericUnit implements Unit {

	private static final long serialVersionUID = 1L;

	private int length;
	private String unit;

	/**
	 * Creates a new numeric CSS unit.
	 * 
	 * @param length The numeric length of the unit
	 * @param unit The unit label
	 * @see <a href="http://w3schools.com/cssref/css_units.asp">CSS Units</a>
	 */

	NumericUnit(final int length, final String unit) {
		this.length = length;
		this.unit = unit;
	}

	@Override
	public final String toString() {
		return length + unit;
	}

}