/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.css;

import junit.framework.Assert;

import org.junit.Test;

public final class AttributeSelectorTest {

	@Test
	public void testNormalDouble() throws Exception {
		String actual = new AttributeSelector("title", "W3Schools").toString();
		Assert.assertEquals("[title=\"W3Schools\"]", actual);
	}

	@Test
	public void testNormalDoubleLong() throws Exception {
		String actual = new AttributeSelector("title", "W3Schools 1 2 3").toString();
		Assert.assertEquals("[title=\"W3Schools 1 2 3\"]", actual);
	}

	@Test
	public void testNormalSingle() throws Exception {
		String actual = new AttributeSelector("title").toString();
		Assert.assertEquals("[title]", actual);
	}

	@Test(expected = IllegalArgumentException.class)
	public void testNullSingle() throws Exception {
		new AttributeSelector(null).toString();
	}

	@Test(expected = IllegalArgumentException.class)
	public void testNullDouble() throws Exception {
		new AttributeSelector(null, null).toString();
	}

	@Test
	public void testValueNull() throws Exception {
		String actual = new AttributeSelector("title", null).toString();
		Assert.assertEquals("[title]", actual);
	}

	@Test
	public void testValueEmpty() throws Exception {
		String actual = new AttributeSelector("title", "").toString();
		Assert.assertEquals("[title]", actual);
	}

}