/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.css;

import junit.framework.Assert;

import org.junit.Test;

import com.osbcp.css.constants.PseudoSelector;

public final class TestCSS_AttributeSelectors {

	@Test
	public void testSingle() throws Exception {

		CSS css = new CSS();
		css.setAttributeSelector("title");
		css.setColor("red");

		Assert.assertEquals(".cf479d19ba2dc90ae9be3d45a51490693[title] {\n	color: red;\n}\n\n", css.toStringBlock());

	}

	@Test
	public void testDouble() throws Exception {

		CSS css = new CSS();
		css.setAttributeSelector("title", "W3Schools");
		css.setColor("red");

		Assert.assertEquals(".cf479d19ba2dc90ae9be3d45a51490693[title=\"W3Schools\"] {\n	color: red;\n}\n\n", css.toStringBlock());

	}

	@Test
	public void testSinglePseudo() throws Exception {

		CSS css = new CSS();
		css.setAttributeSelector("title");
		css.setColor("red");

		css.addPseudoSelector(PseudoSelector.FOCUS, new CSS() {

			{
				setBackgroundColor("blue");
			}

		});

		StringBuilder expected = new StringBuilder();

		expected.append(".cf479d19ba2dc90ae9be3d45a51490693[title] {\n");
		expected.append("	color: red;\n");
		expected.append("}\n");
		expected.append("\n");
		expected.append(".cf479d19ba2dc90ae9be3d45a51490693:focus[title] {\n");
		expected.append("	background-color: blue;\n");
		expected.append("}\n");
		expected.append("\n");

		Assert.assertEquals(expected.toString(), css.toStringBlock());

	}

	@Test
	public void testDoublePseudo() throws Exception {

		CSS css = new CSS();
		css.setAttributeSelector("title", "W3Schools");
		css.setColor("red");

		css.addPseudoSelector(PseudoSelector.FOCUS, new CSS() {

			{
				setBackgroundColor("blue");
			}

		});

		StringBuilder expected = new StringBuilder();

		expected.append(".cf479d19ba2dc90ae9be3d45a51490693[title=\"W3Schools\"] {\n");
		expected.append("	color: red;\n");
		expected.append("}\n");
		expected.append("\n");
		expected.append(".cf479d19ba2dc90ae9be3d45a51490693:focus[title=\"W3Schools\"] {\n");
		expected.append("	background-color: blue;\n");
		expected.append("}\n");
		expected.append("\n");

		Assert.assertEquals(expected.toString(), css.toStringBlock());

	}

}